package gov.usgs.earthquake.nshmp.netcdf.data;

import static com.google.common.base.Preconditions.checkState;

import java.util.List;
import java.util.Map;

import gov.usgs.earthquake.nshmp.gmm.Imt;
import gov.usgs.earthquake.nshmp.gmm.NehrpSiteClass;

/**
 * NetCDF data for hazard curves.
 *
 * @author U.S. Geological Survey
 */
public class NetcdfDataHazardCurves extends NetcdfData {

  private final Map<Imt, double[]> imls;

  NetcdfDataHazardCurves(Builder builder) {
    super(builder);
    imls = builder.imls;
  }

  /**
   * Returns the Imls
   */
  public Map<Imt, double[]> imls() {
    return imls;
  }

  /**
   * Returns the number of Imls
   */
  public int nIml() {
    return imls.values().iterator().next().length;
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder extends NetcdfData.Builder {
    Map<Imt, double[]> imls;

    Builder() {
      super();
    }

    public Builder imls(Map<Imt, double[]> imls) {
      this.imls = imls;
      return this;
    }

    @Override
    public Builder imts(List<Imt> imts) {
      super.imts(imts);
      return this;
    }

    @Override
    public Builder latitudes(double[] latitudes) {
      super.latitudes(latitudes);
      return this;
    }

    @Override
    public Builder longitudes(double[] longitudes) {
      super.longitudes(longitudes);
      return this;
    }

    @Override
    public Builder scienceBaseMetadata(ScienceBaseMetadata scienceBaseMetadata) {
      super.scienceBaseMetadata(scienceBaseMetadata);
      return this;
    }

    @Override
    public Builder siteClasses(List<NehrpSiteClass> siteClasses) {
      super.siteClasses(siteClasses);
      return this;
    }

    @Override
    public Builder vs30Map(Map<NehrpSiteClass, Double> vs30Map) {
      super.vs30Map(vs30Map);
      return this;
    }

    public NetcdfDataHazardCurves build() {
      checkBuildState();
      return new NetcdfDataHazardCurves(this);
    }

    void checkBuildState() {
      super.checkBuildState();
      checkState(!imls.isEmpty(), "Must add imls");
    }
  }
}
